==> python-glpk_0.1.16.orig.tar.gz: python-glpk-0.1.16/glpkpi.c <==
/* glpkpi.c (C functions for setting/canceling printing in the stdout) */

/*----------------------------------------------------------------------
-- This code is part of the Python-GLPK interface.
--
-- Copyright (C) 2005, Joao Pedro Pedroso
-- Faculdade de Ciencias, Universidade do Porto
-- Porto, Portugal. All rights reserved. E-mail: <jpp@fc.up.pt>.
--
-- GLPK is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- GLPK is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with GLPK; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-- 02110-1301, USA.
----------------------------------------------------------------------*/

#include <stdlib.h>
#include <glpk.h>

/* 
   copied from glplib.h:
*/
void _glp_lib_print_hook(int (*func)(void *info, char *buf), void *info);
/* install print hook routine */


/*
  written by jpp
*/
int no_print_hook(void *info,  char *msg) {
  return 1;
}

void lpx_no_print() {
  _glp_lib_print_hook(no_print_hook, NULL);
}

void lpx_do_print() {
  _glp_lib_print_hook(NULL, NULL);
}

==> python-glpk_0.1.38.orig.tar.gz: python-glpk_0.1.38/glpkpi.c <==
/* glpkpi.c (C functions for setting/canceling printing in the stdout) */

/*----------------------------------------------------------------------
-- This code is part of the Python-GLPK interface.
--
-- Copyright (C) 2005-2009, Joao Pedro Pedroso
-- Faculdade de Ciencias, Universidade do Porto
-- Porto, Portugal. All rights reserved. E-mail: <jpp@fc.up.pt>.
--
-- GLPK is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- GLPK is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with GLPK; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-- 02110-1301, USA.
----------------------------------------------------------------------*/

#include <stdlib.h>
#include <glpk.h>


/*
  written by jpp
*/
static int no_print_hook(void *info, const char *s) {
  return 1;
}

void glp_no_print() {
  glp_term_hook(no_print_hook, NULL);
}

void glp_do_print() {
  glp_term_hook(NULL, NULL);
}

/* !!! not defined in glpk's library !!! */
_glp_data *_glp_sds_open(const char *fname) {}
void _glp_sds_jump(_glp_data *data, void *jump) {}
void _glp_sds_error(_glp_data *data, const char *fmt, ...) {}
void _glp_sds_warning(_glp_data *data, const char *fmt, ...) {}
int _glp_sds_int(_glp_data *data) {}
double _glp_sds_num(_glp_data *data) {}
const char *_glp_sds_item(_glp_data *data) {}
const char *_glp_sds_text(_glp_data *data) {}
int _glp_sds_line(_glp_data *data) {}
void _glp_sds_close(_glp_data *data) {}
